@@ -13,7 +13,7 @@ parser = argparse.ArgumentParser(prog='watch-fs')
 parser.add_argument(
     'command', help="The command to run when files change")
 parser.add_argument(
-    '-d', action='append', metavar='DIR', destination='paths',
+    '-d', action='append', metavar='DIR', dest='paths',
     help="A directory to watch. Can be used more than once.")
 
 class Command(object):
